@@ -1,7 +1,6 @@
 import yaml
-from docstring_parser import parse
+from .reference import Reference
 from ...plugin import Plugin
-from ... import helpers
 from ... import errors
 
 
@@ -20,12 +19,15 @@ class ReferencePlugin(Plugin):
     def process_snippet(self, snippet):
         if snippet.type == "reference" and snippet.lang == "yaml":
             spec = yaml.safe_load(str(snippet.input).strip())
-            object = helpers.load_object(spec.get("path"))
-            if not object:
-                raise errors.Error(f"No object found: {spec}")
+            references = []
+            for pointer in spec.get("references", []):
+                reference = Reference.from_name(pointer)
+                references.append(reference)
+            if not references:
+                raise errors.Error(f"No references found: {spec}")
             context = {}
-            context["name"] = object.__name__
-            context["info"] = parse(object.__doc__)
+            context["references"] = references
+            context["level"] = spec.get("level", 3)
             snippet.output = self.read_asset("markup.html", **context)
 
     def process_markup(self, markup):
