@@ -17,7 +17,7 @@ class SearchPlugin(Plugin):
             item = {}
             item["name"] = document.get_plugin("site").name
             item["path"] = document.path
-            item["relpath"] = helpers.get_relpath(document.path, self.document.path)
+            item["relpath"] = helpers.get_url_relpath(document.path, self.document.path)
             item["text"] = document.content
             items.append(item)
         return items
